window.Gleam.initSearch([{"doc":"hexdocs_offline","title":"hexdocs_offline","content":"# Hexdocs Offline\n\n[![Package Version](https://img.shields.io/hexpm/v/hexdocs_offline)](https://hex.pm/packages/hexdocs_offline)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/hexdocs_offline/)\n\nDownload an offline version of the hexdocs of your projects dependencies to a local folder.\n\nUseful for if you are travelling a lot and do not have a great or any internet connection at all times.\nOr if you just want to have a centralized index page for all of the hexdocs of your dependencies and close 10 of those tabs.\n\n# How?\n\nAll this package does is fetch the dependencies from the `gleam.toml` file and uses\n`mix hex.docs fetch ...` to download a local version of them.\n\n# Demo\n\n[HEXDOCS.html](./HEXDOCS.html) for this project\n\n# Platform Support\n\nThis package works fine on `macos` and `linux`. It has **not** been tested on Windows\nand will probably fail due to the `~/.hex` directory default.\n\n# Required Software\n\nApart from [Gleam](https://gleam.run/) you will need have to need\n[Mix](https://hexdocs.pm/mix/Mix.html) installed on your system.\n\n# Usage\n\n## Installation\n```sh\ngleam add hexdocs_offline --dev\n```\n\n## Option 1: Default Config\n[Example Repository](./examples/default_config)\n\n```sh\ngleam run -m hexdocs_offline\n```\n\nThis will generate the hexdocs with the default configuration:\n- gleam_path: `./gleam.toml`\n- manifest_path: `./manifest.toml`\n- output_path: `./HEXDOCS.html`\n- new_tab: `True` *(opens links as a new tab)*\n- include_dev: `True` *(includes dev dependencies)*\n- ignore_deps: `[]` *(take all dependencies into consideration)*\n\n## Option 2: Custom Config\n[Example Repository](./examples/custom_config)\n\n```gleam\n//// file `src/dev/generate_hexdocs.gleam`\nimport hexdocs_offline.{generate}\nimport hexdocs_offline/config.{\n  default_config, with_ignore_deps, with_include_dev, with_output_path,\n}\n\npub fn main() {\n  let config =\n    default_config()\n    |&gt; with_output_path(&quot;./HEXDOCS.html&quot;)\n    |&gt; with_include_dev(False)\n    |&gt; with_ignore_deps([&quot;...&quot;])\n\n  generate(config)\n}\n```\n\n```sh\ngleam run -m dev/generate_hexdocs\n```\n\n# Notices\n- you might want to add the resulting `HEXDOCS.html` file to your `.gitignore`\n\n# Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n\n# Acknowledgements\n\n- Thank you `simplecss` ([GitHub](https://github.com/kevquirk/simple.css/)) (https://github.com/kevquirk)\n- Thank you [Mix Docs](https://hexdocs.pm/hex/Mix.Tasks.Hex.Docs.html) for saving me a lot of pain of recreating this myself\n- Thank you to `go_over` ([Hex](https://hex.pm/packages/go_over), [GitHub](https://github.com/bwireman/go-over)) for inspiring the code that reads out the `gleam.toml` file (https://github.com/bwireman)\n- Thank you to `squirrel` ([Hex](https://hex.pm/packages/squirrel), [GitHub](https://github.com/giacomocavalieri/squirrel)) for a lot of the code and repository structure inspiration (https://github.com/giacomocavalieri)\n\n# License\n[Apache License, Version 2.0](./LICENSE)\n","url":"index.html"},{"doc":"hexdocs_offline/config","title":"Config","content":"pub type Config {\n  Config(\n    manifest_path: String,\n    gleam_path: String,\n    output_path: String,\n    include_dev: Bool,\n    new_tab: Bool,\n    ignore_deps: List(String),\n    hex_home: String,\n  )\n}\n\nConfig(\n  manifest_path: String,\n  gleam_path: String,\n  output_path: String,\n  include_dev: Bool,\n  new_tab: Bool,\n  ignore_deps: List(String),\n  hex_home: String,\n)\n\n\nSynonyms:\nhexdocs_offline/config.Config\nhexdocs_offline/config Config","url":"hexdocs_offline/config.html#Config"},{"doc":"hexdocs_offline/config","title":"default_config","content":"pub fn default_config() -&gt; Config\n\nSynonyms:\nhexdocs_offline/config.default_config\nhexdocs_offline/config default_config","url":"hexdocs_offline/config.html#default_config"},{"doc":"hexdocs_offline/config","title":"default_gleam_path","content":"pub fn default_gleam_path() -&gt; String\n\nSynonyms:\nhexdocs_offline/config.default_gleam_path\nhexdocs_offline/config default_gleam_path","url":"hexdocs_offline/config.html#default_gleam_path"},{"doc":"hexdocs_offline/config","title":"default_hex_home","content":"pub fn default_hex_home() -&gt; String\n read more here: https://hexdocs.pm/hex/Mix.Tasks.Hex.Config.html\nSynonyms:\nhexdocs_offline/config.default_hex_home\nhexdocs_offline/config default_hex_home","url":"hexdocs_offline/config.html#default_hex_home"},{"doc":"hexdocs_offline/config","title":"default_manifest_path","content":"pub fn default_manifest_path() -&gt; String\n\nSynonyms:\nhexdocs_offline/config.default_manifest_path\nhexdocs_offline/config default_manifest_path","url":"hexdocs_offline/config.html#default_manifest_path"},{"doc":"hexdocs_offline/config","title":"default_output_path","content":"pub fn default_output_path() -&gt; String\n\nSynonyms:\nhexdocs_offline/config.default_output_path\nhexdocs_offline/config default_output_path","url":"hexdocs_offline/config.html#default_output_path"},{"doc":"hexdocs_offline/config","title":"with_file_path","content":"pub fn with_file_path(\n  config: Config,\n  manifest_path: String,\n) -&gt; Config\n\nSynonyms:\nhexdocs_offline/config.with_file_path\nhexdocs_offline/config with_file_path","url":"hexdocs_offline/config.html#with_file_path"},{"doc":"hexdocs_offline/config","title":"with_gleam_path","content":"pub fn with_gleam_path(\n  config: Config,\n  gleam_path: String,\n) -&gt; Config\n\nSynonyms:\nhexdocs_offline/config.with_gleam_path\nhexdocs_offline/config with_gleam_path","url":"hexdocs_offline/config.html#with_gleam_path"},{"doc":"hexdocs_offline/config","title":"with_hex_home","content":"pub fn with_hex_home(config: Config, hex_home: String) -&gt; Config\n\nSynonyms:\nhexdocs_offline/config.with_hex_home\nhexdocs_offline/config with_hex_home","url":"hexdocs_offline/config.html#with_hex_home"},{"doc":"hexdocs_offline/config","title":"with_ignore_deps","content":"pub fn with_ignore_deps(\n  config: Config,\n  ignore_deps: List(String),\n) -&gt; Config\n\nSynonyms:\nhexdocs_offline/config.with_ignore_deps\nhexdocs_offline/config with_ignore_deps","url":"hexdocs_offline/config.html#with_ignore_deps"},{"doc":"hexdocs_offline/config","title":"with_include_dev","content":"pub fn with_include_dev(\n  config: Config,\n  include_dev: Bool,\n) -&gt; Config\n\nSynonyms:\nhexdocs_offline/config.with_include_dev\nhexdocs_offline/config with_include_dev","url":"hexdocs_offline/config.html#with_include_dev"},{"doc":"hexdocs_offline/config","title":"with_new_tab","content":"pub fn with_new_tab(config: Config, new_tab: Bool) -&gt; Config\n\nSynonyms:\nhexdocs_offline/config.with_new_tab\nhexdocs_offline/config with_new_tab","url":"hexdocs_offline/config.html#with_new_tab"},{"doc":"hexdocs_offline/config","title":"with_output_path","content":"pub fn with_output_path(\n  config: Config,\n  output_path: String,\n) -&gt; Config\n\nSynonyms:\nhexdocs_offline/config.with_output_path\nhexdocs_offline/config with_output_path","url":"hexdocs_offline/config.html#with_output_path"},{"doc":"hexdocs_offline/config","title":"hexdocs_offline/config","content":"\n This module holds the main Config record type.\n It is used to identify the parameters of which `gleam.toml` file\n to use and where to put the resulting html files.\n","url":"hexdocs_offline/config.html"},{"doc":"hexdocs_offline","title":"generate","content":"pub fn generate(conf: Config) -&gt; Nil\n\nSynonyms:\nhexdocs_offline.generate\nhexdocs_offline generate","url":"hexdocs_offline.html#generate"},{"doc":"hexdocs_offline","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\nhexdocs_offline.main\nhexdocs_offline main","url":"hexdocs_offline.html#main"},{"doc":"hexdocs_offline","title":"hexdocs_offline","content":"","url":"hexdocs_offline.html"}]);